@@ -219,43 +219,3 @@ close(RDSAT.file)
 
 invisible()   
 }     
-
-#' Writes out the RDS tree in Gephi format
-#' @param x An rds.data.frame.
-#' @param file a character vector representing a file.
-#' @param scale a positive scaler to scale the outputed positions. 
-#' @details All the variables in the RDS data set are exported as well.
-#' \code{paste0(file,".GEXF")} contains the nodal attributes and edge information.
-#' @export
-write.gephi <- function(x, file=NULL, scale=20){
-	if(is.null(file)){
-	  file<-paste(paste(getwd(),substitute(x),sep="/"),"gexf",sep=".")
-	}
-	x <- as.rds.data.frame(x)
-	id <- as.char(get.id(x))
-	rid <- as.char(get.rid(x))
-	sid <- as.char(get.seed.rid(x))
-	w <- get.wave(x)
-	el <- cbind(rid,id)
-	el <- el[order(w),]
-	el <- el[rid!=sid,]
-	
-	nVizAtt <- t(col2rgb((rid==0)+1, alpha=TRUE))
-	nVizAtt <- nVizAtt / max(nVizAtt,na.rm=TRUE)
-        t <- reingold.tilford.plot(x, plot=FALSE)
-	nVizAtt <- list(position=data.frame(scale*t,0), color=nVizAtt)
-
-	a=rgexf::write.gexf(
-	  nodes = cbind(id,id),
-	  edges = el,
-	  nodesAtt = x,
-	  defaultedgetype = "directed",
-	  nodesVizAtt = nVizAtt
-	)
-	output <- file(description=file,open="w",encoding='UTF-8')
-	write(a$graph, file=output)
-	close.connection(output)
-#	message('GEXF graph successfully written at:\n',normalizePath(file))
-	
-	invisible()   
-}     
